Presentación
============

.. image:: images/pilas-logo.png

Pilas es una herramienta para construir videojuegos
de manera sencilla y didáctica. También conocido como
"motor" o "biblioteca" de videojuegos.

El objetivo de este documento es presentar
las características del motor, y dar un recorrido
general por todos los componentes que se pueden
utilizar.

Es una buena idea tener este documento como referencia, e
ir experimentando con los ejemplos paso a paso
y elaborando un juego.


¿Por qué pilas?
---------------

Pilas está focalizado en ofrecer ayuda a los
desarrolladores de juegos casuales y novatos que quieran
hacer sus primeros videojuegos, ofreciendo una
colección importante de actores, escenas prediseñadas
y rutinas para facilitar las tareas más comunes
del desarrollo.

Pensamos que pilas es una gran oportunidad de acercar
el desarrollo de videojuegos a todas las personas, principalmente
jóvenes con interés en aprender a programar computadoras y
darle vida a sus ideas.

Pilas está profundamente inspirada en las ideas de Seymour
Papert, logo y bibliotecas de videjuegos modernas como ``cocos2d``,
``pygame``, ``rabbyt`` y ``squeak``.


Características
---------------

Estas son algunas de las características
técnicas que podemos resumir de pilas.

- Es multiplataforma (Funciona sobre GNU/Linux y Windows)
- Cuenta con objetos prediseñados para agilizar el desarrollo.
- Tiene documentación completamente en español.
- Se utiliza desde python, lo que permite usarla desde sesiones interactivas.
- Incluye interacción con el motor de física pybox2d.
- Es software libre.
- Cuenta con varios ejemplos y tutoriales para ir paso a paso.

A lo largo del documento se dará un repaso mas completo
de cada una de estas características y mas.

Sitio oficial
-------------

Para mas información sobre el motor puedes visitar el
sitio web:

http://www.pilas-engine.com.ar
